pub trait ArrayLike<A> {
// Required method
fn into_dyn_view(&self) -> ArrayView<'_, A, IxDyn>;
}Expand description
This trait is implemented for all ArrayBase variants and is parameterized by the data type.
It’s here so einsum and the other functions accepting a list of operands
can take a slice &[&dyn ArrayLike<A>] where the elements of the slice can have
different numbers of dimensions and can be a mixture of Array and ArrayView.
Required Methods
fn into_dyn_view(&self) -> ArrayView<'_, A, IxDyn>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".